# This file was generated by generate_stubs.rb
# Do not edit this file directly.

# A OneofDescriptor provides information about the Protobuf definition of a
# oneof inside a {Descriptor}.
class Google::Protobuf::OneofDescriptor

  # Creates a new, empty, oneof descriptor. The oneof may only be modified prior
  # to being added to a message descriptor which is subsequently added to a pool.
  def initialize; end

  # Returns the name of this oneof.
  # 
  # @return [String]
  def name; end

  # Iterates through fields in this oneof, yielding to the block on each one.
  # 
  # @yield [FieldDescriptor]
  # @return [nil]
  def each(&block); end

  # Returns the
  # {https://github.com/protocolbuffers/protobuf/blob/v30.2/src/google/protobuf/descriptor.proto#L824
  # OneofOptions} for this {OneofDescriptor}.
  # 
  # @return [OneofOptions]
  def options; end

  # Returns the
  # {https://github.com/protocolbuffers/protobuf/blob/v30.2/src/google/protobuf/descriptor.proto#L343
  # OneofDescriptorProto} of this {OneofDescriptor}.
  # 
  # @return [OneofDescriptorProto]
  def to_proto; end

end # class Google::Protobuf::OneofDescriptor
