# This file was generated by generate_stubs.rb
# Do not edit this file directly.

# A MethodDescriptor provides information about the Protobuf definition of a
# method inside an RPC service.
class Google::Protobuf::MethodDescriptor

  # Returns the name of this method
  # 
  # @return [String]
  def name; end

  # Returns the
  # {https://github.com/protocolbuffers/protobuf/blob/v30.2/src/google/protobuf/descriptor.proto#L927
  # MethodOptions} for this {MethodDescriptor}.
  # 
  # @return [MethodOptions]
  def options; end

  # Returns the {Descriptor} for the request message type of this method
  # 
  # @return [Descriptor]
  def input_type; end

  # Returns the {Descriptor} for the response message type of this method
  # 
  # @return [Descriptor]
  def output_type; end

  # Returns whether or not this is a streaming request method
  # 
  # @return [Boolean]
  def client_streaming; end

  # Returns the
  # {https://github.com/protocolbuffers/protobuf/blob/v30.2/src/google/protobuf/descriptor.proto#L394
  # MethodDescriptorProto} of this {MethodDescriptor}.
  # 
  # @return [MethodDescriptorProto]
  def to_proto; end

  # Returns whether or not this is a streaming response method
  # 
  # @return [Boolean]
  def server_streaming; end

end # class Google::Protobuf::MethodDescriptor
