# This file was generated by generate_stubs.rb
# Do not edit this file directly.

# A ServiceDescriptor provides information about the Protobuf definition of an
# RPC service.
class Google::Protobuf::ServiceDescriptor

  # Returns the name of this service.
  # 
  # @return [String]
  def name; end

  # Returns the {FileDescriptor} object this service belongs to.
  # @return [FileDescriptor]
  def file_descriptor; end

  # Iterates over methods in this service, yielding to the block on each one.
  # 
  # @yield [MethodDescriptor]
  # @return [nil]
  def each(&block); end

  # Returns the
  # {https://github.com/protocolbuffers/protobuf/blob/v30.2/src/google/protobuf/descriptor.proto#L901
  # ServiceOptions} for this {ServiceDescriptor}.
  # 
  # @return [ServiceOptions]
  def options; end

  # Returns the
  # {https://github.com/protocolbuffers/protobuf/blob/v30.2/src/google/protobuf/descriptor.proto#L386
  # ServiceDescriptorProto} of this {ServiceDescriptor}.
  # 
  # @return [ServiceDescriptorProto]
  def to_proto; end

end # class Google::Protobuf::ServiceDescriptor
